==> ayechat-0.21.2.dev20251108174312.tar.gz: ayechat-0.21.2.dev20251108174312/tests/ua/ui_tests.md <==
# User Acceptance Tests for UI Functions in Aye

This document outlines user acceptance tests (UATs) for UI functions in Aye, implemented in `src/aye/ui.py`. The module provides display functions for welcome messages, help, prompts, errors, and status updates. Tests cover CLI and chat interactions where UI prints are shown. Emphasize proper formatting, colors, and user feedback in terminal.

## Test Environment Setup
- Run in a color-supporting terminal.
- Test via CLI commands or chat sessions.
- Observe printed output directly.

## Test Cases

### 1. Welcome Message

#### UAT-1.1: Display Welcome on Chat Start
- **Given**: Starting `aye chat`.
- **When**: Chat initializes.
- **Then**: Prints welcome message with bold cyan.
- **Verification**: Check output format.

### 2. Help Message

#### UAT-2.1: Show Help in Chat
- **Given**: In chat, typing "help".
- **When**: Command executed.
- **Then**: Prints help with commands.
- **Verification**: Ensure all commands listed.

### 3. Prompt Display

#### UAT-3.1: Show Prompt in Chat
- **Given**: Chat ready for input.
- **When**: Prompting for user input.
- **Then**: Displays "(ツ» " .
- **Verification**: Check prompt string.

### 4. Assistant Response

#### UAT-4.1: Display Response in Chat
- **Given**: After LLM response.
- **When**: Printing summary.
- **Then**: Shows bot face and summary.
- **Verification**: Format with color.

### 5. Error Display

#### UAT-5.1: Show Error in Chat/CLI
- **Given**: Exception occurs.
- **When**: Printing error.
- **Then**: Displays in red.
- **Verification**: Error message shown.

### 6. Files Updated

#### UAT-6.1: Show Updated Files
- **Given**: Files changed.
- **When**: Printing update.
- **Then**: Lists files.
- **Verification**: Comma-separated.

### 7. No Files Changed

#### UAT-7.1: Show No Changes
- **Given**: No updates.
- **When**: Printing.
- **Then**: Message in yellow.
- **Verification**: Correct padding.

## Notes
- Uses Rich for formatting.
- Colors: Cyan, red, green, yellow.
- Ensure terminal supports colors.

==> ayechat-0.21.5.dev20251122145953.tar.gz: ayechat-0.21.5.dev20251122145953/tests/ua/ui_tests.md <==
# User Acceptance Tests for UI Functions in Aye

This document outlines user acceptance tests (UATs) for UI functions in Aye, implemented in `aye/presenter/repl_ui.py` and related presenter modules. The modules provide display functions for welcome messages, help, prompts, errors, and status updates. Tests cover CLI and chat interactions where UI prints are shown. Emphasize proper formatting, colors, and user feedback in terminal.

## Test Environment Setup
- Run in a color-supporting terminal.
- Test via CLI commands or chat sessions.
- Observe printed output directly.

## Test Cases

### 1. Welcome Message

#### UAT-1.1: Display Welcome on Chat Start
- **Given**: Starting `aye chat`.
- **When**: Chat initializes.
- **Then**: Prints welcome message with bold cyan.
- **Verification**: Check output format.

### 2. Help Message

#### UAT-2.1: Show Help in Chat
- **Given**: In chat, typing "help".
- **When**: Command executed.
- **Then**: Prints help with commands.
- **Verification**: Ensure all commands listed.

### 3. Prompt Display

#### UAT-3.1: Show Prompt in Chat
- **Given**: Chat ready for input.
- **When**: Prompting for user input.
- **Then**: Displays "(ツ» " .
- **Verification**: Check prompt string.

### 4. Assistant Response

#### UAT-4.1: Display Response in Chat
- **Given**: After LLM response.
- **When**: Printing summary.
- **Then**: Shows bot face and summary.
- **Verification**: Format with color.

### 5. Error Display

#### UAT-5.1: Show Error in Chat/CLI
- **Given**: Exception occurs.
- **When**: Printing error.
- **Then**: Displays in red.
- **Verification**: Error message shown.

### 6. Files Updated

#### UAT-6.1: Show Updated Files
- **Given**: Files changed.
- **When**: Printing update.
- **Then**: Lists files.
- **Verification**: Comma-separated.

### 7. No Files Changed

#### UAT-7.1: Show No Changes
- **Given**: No updates.
- **When**: Printing.
- **Then**: Message in yellow.
- **Verification**: Correct padding.

## Notes
- Uses Rich for formatting.
- Colors: Cyan, red, green, yellow.
- Ensure terminal supports colors.
